@@ -33,13 +33,13 @@ comment q|
                 perl script.pl
 
         or you can just try some of the commands illustrated
-        in the demos by just retyping them at the perldl
-        command prompt.
+        in the demos by just retyping them at the perldl or pdl
+        'pdl>' command prompt.
 |;
 
 act q|
-	$a = zeroes 5,5; # 5x5 matrix
-	output $a;
+	$x = zeroes 5,5; # 5x5 matrix
+	output $x;
 |;
 
 act q|
@@ -50,21 +50,21 @@ act q|
 |;
 
 act q|
-	$a ++;      # Operators like increment work..
-	output $a;
+	$x ++;      # Operators like increment work..
+	output $x;
 |;
 
 act q|
 	# xvals and yvals (yes, there is also zvals...)
 	# give you piddles which give the coordinate value.
-	$b = xvals $a;
-	output $b;
+	$y = xvals $x;
+	output $y;
 |;
 
 act q|
 	# So you can do things like
-	$b = $a + 0.1 * xvals($a) + 0.01 * yvals($a);
-	output $b;
+	$y = $x + 0.1 * xvals($x) + 0.01 * yvals($x);
+	output $y;
 |;
 
 act q|
@@ -76,41 +76,41 @@ act q|
 
 act q|
 	# You can also take slices:
-	output $b;
-	output $b->slice(":,2:3");  # rows 2 and 3
+	output $y;
+	output $y->slice(":,2:3");  # rows 2 and 3
 |;
 act q|
-	output $b->slice("2:3,:");  # or columns 2 and 3
+	output $y->slice("2:3,:");  # or columns 2 and 3
 |;
 
 act q|
-	output $b;
-	output $b->diagonal(0,1),"\n"; # 0 and 1 are the dimensions
+	output $y;
+	output $y->diagonal(0,1),"\n"; # 0 and 1 are the dimensions
 |;
 
 act q|
 	# One of the really nifty features is that the
 	# slices are actually references back to the original
 	# piddle:
-	$diag = $b->diagonal(0,1);
-	output $b;
+	$diag = $y->diagonal(0,1);
+	output $y;
 	output $diag,"\n";
 	$diag+=100;
 	output "AFTER:\n";
 	output $diag,"\n";
-	output "Now, guess what \$b looks like?\n";
+	output "Now, guess what \$y looks like?\n";
 |;
 
 act q|
 	# Yes, it has changed:
-	output $b;
+	output $y;
 |;
 
 act q|
 	# Another example (we only modify elements 0,2 and 4 of
         # each row):
-	$t = $b->slice("0:4:2"); $t += 50;
-	output $b;
+	$t = $y->slice("0:4:2"); $t += 50;
+	output $y;
 |;
 
 act q|
@@ -118,35 +118,35 @@ act q|
 	# and PDL::Slices - we can't show you all but here are some
 	# examples:
 
-	output $b;
-	output $b->sum, "\n";
-	output $b->sumover,"\n"; # Only over first dim.
+	output $y;
+	output $y->sum, "\n";
+	output $y->sumover,"\n"; # Only over first dim.
 |;
 
 act q|
-	output $b->xchg(0,1);
-	output $b->minimum,"\n"; # over first dim.
-	output $b->min,"\n";
+	output $y->xchg(0,1);
+	output $y->minimum,"\n"; # over first dim.
+	output $y->min,"\n";
 |;
 
 act q|
-	output $b->random;
+	output $y->random;
 |;
 
 act q|
 	# Here are some more advanced tricks for selecting
 	# parts of 1-D vectors:
-	$a = (xvals 12)/3;
-	$i = which(sin($a) > 0.5);   # Indices of those sines > 0.5
-	output $a,"\n";
+	$x = (xvals 12)/3;
+	$i = which(sin($x) > 0.5);   # Indices of those sines > 0.5
+	output $x,"\n";
 	output $i,"\n";
-	output $a->index($i),"\n";
+	output $x->index($i),"\n";
              # and we can have the effect of the last command in one
              # go using 'where' instead of 'which' and 'index' as in
-        output $a->where(sin($a) > 0.5),"\n";
+        output $x->where(sin($x) > 0.5),"\n";
              # and finally take the sin of these elements
              # (to show that these are indeed the correct ones)
-	output sin($a->index($i)),"\n";
+	output sin($x->index($i)),"\n";
 |;
 
 comment q|
@@ -154,7 +154,7 @@ comment q|
 	of the basic capabilities of PDL.
 
 	We encourage you to play with these commands in
-        the perldl shell and use its online help support
+        the perldl or pdl2 shell and use its online help support
 	to find out more about these and other commands and
 	features of PDL.
 
